==> haskell-colourista-0.1.0.2-38-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.2
visibility:           public
id:                   colourista-0.1.0.2-35IwqNcCq1C542okgJeRXx
key:                  colourista-0.1.0.2-35IwqNcCq1C542okgJeRXx
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  4face900b0ebfd519f4cd408e7046fac
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colourista
hs-libraries:         HScolourista-0.1.0.2-35IwqNcCq1C542okgJeRXx
depends:
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colourista-0.1.0.2-40-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.2
visibility:           public
id:                   colourista-0.1.0.2-4Iz8dcMLyzi4Torlu4KhPb
key:                  colourista-0.1.0.2-4Iz8dcMLyzi4Torlu4KhPb
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  11ce9a6062b222499d1e7a95984f567f
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colourista
hs-libraries:         HScolourista-0.1.0.2-4Iz8dcMLyzi4Torlu4KhPb
depends:
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
